## License

Aiquarium is open source under the [AGPL v3](LICENSE).

For commercial use cases that require a proprietary license
(enterprise deployments, white-labeling, OEM), 
contact hello@aiquarium.dev

Tu es un dev qui l'utilise dans son projet    →  AGPL ✅ gratuit
Tu es une boîte qui le self-host en interne   →  AGPL ✅ gratuit
Tu veux créer un SaaS basé sur Aiquarium      →  Licence commerciale 💰
Tu veux le modifier sans publier tes changes  →  Licence commerciale 💰
